==> v0.2.0.zip: buster/README.md <==
<p align="center"><img src="https://i.imgur.com/4DvR5ip.png"></p>
<h1 align="center">Buster: Captcha Solver for Humans</h1>

<p align="center">
  </br></br>
  <a href="">
    <img src="https://i.imgur.com/q6E8SOD.png" alt="Chrome Web Store"></a>
  <a href="https://addons.mozilla.org/en-US/firefox/addon/buster-captcha-solver/">
    <img src="https://i.imgur.com/dvof8rG.png" alt="Firefox add-ons"></a>
  <a href="https://addons.opera.com/en/extensions/details/buster-captcha-solver-for-humans/">
    <img src="https://i.imgur.com/wK10qEV.png" alt="Opera add-ons"></a>
  </br></br>
</p>

## Supporting the Project

The continued development of Buster is made possible
thanks to the support of awesome backers. If you'd like to join them,
please consider contributing with [Patreon](https://www.patreon.com/dessant),
[PayPal](https://www.paypal.me/ArminSebastian) or [Bitcoin](https://goo.gl/uJUAaU).

## Description

> Obviously, this blue part here is the land.
>
> — <cite>Byron "Buster" Bluth, reading a map</cite>

Buster is a browser extension which helps you to solve difficult captchas
by completing reCAPTCHA audio challenges using automatic speech recognition.
Challenges are solved by clicking on the extension button at the bottom
of the reCAPTCHA widget.

reCAPTCHA challenges remain a considerable burden on the web,
delaying and often blocking our access to services and information
depending on our physical and cognitive abilities, our social
and cultural background, and the devices or networks we connect from.

The difficulty of captchas can be so out of balance,
that sometimes they seem friendlier to bots than they are to humans.

The goal of this project is to improve our experience with captchas,
by giving us easy access to solutions already utilized by automated systems.

## Screenshots

<p>
  <img width="420" src="https://i.imgur.com/hTqeN4z.png">
  <img width="420" src="https://i.imgur.com/o0qqDd5.png">
</p>

## License

Copyright (c) 2018 Armin Sebastian

This software is released under the terms of the GNU General Public License v3.0.
See the [LICENSE](LICENSE) file for further information.

==> v1.2.1.zip: buster/README.md <==
<p align="center"><img src="https://i.imgur.com/4DvR5ip.png"></p>
<h1 align="center">Buster: Captcha Solver for Humans</h1>

<p align="center">
  </br></br>
  <a href="https://chrome.google.com/webstore/detail/mpbjkejclgfgadiemmefgebjfooflfhl">
    <img src="https://i.imgur.com/B0i5sn3.png" alt="Chrome Web Store"></a>
  <a href="https://addons.mozilla.org/en-US/firefox/addon/buster-captcha-solver/">
    <img src="https://i.imgur.com/kMH6r1a.png" alt="Firefox add-ons"></a>
  <a href="https://microsoftedge.microsoft.com/addons/detail/admkpobhocmdideidcndkfaeffadipkc">
    <img src="https://i.imgur.com/n49Wiu2.png" alt="Microsoft Store"></a>
  <a href="https://addons.opera.com/en/extensions/details/buster-captcha-solver-for-humans/">
    <img src="https://i.imgur.com/wK10qEV.png" alt="Opera add-ons"></a>
  </br></br>
</p>

## Supporting the Project

The continued development of Buster is made possible
thanks to the support of awesome backers. If you'd like to join them,
please consider contributing with
[Patreon](https://armin.dev/go/patreon?pr=buster&src=repo),
[PayPal](https://armin.dev/go/paypal?pr=buster&src=repo) or
[Bitcoin](https://armin.dev/go/bitcoin?pr=buster&src=repo).

## Description

> Obviously, this blue part here is the land.
>
> — <cite>Byron "Buster" Bluth, reading a map</cite>

Buster is a browser extension which helps you to solve difficult captchas
by completing reCAPTCHA audio challenges using speech recognition.
Challenges are solved by clicking on the extension button at the bottom
of the reCAPTCHA widget.

reCAPTCHA challenges remain a considerable burden on the web,
delaying and often blocking our access to services and information
depending on our physical and cognitive abilities, our social
and cultural background, and the devices or networks we connect from.

The difficulty of captchas can be so out of balance,
that sometimes they seem friendlier to bots than they are to humans.

The goal of this project is to improve our experience with captchas,
by giving us easy access to solutions already utilized by automated systems.

## Screenshots

<p>
  <img width="414" src="https://i.imgur.com/hTqeN4z.png">
  <img width="414" src="https://i.imgur.com/o0qqDd5.png">
</p>

## License

Copyright (c) 2018-2021 Armin Sebastian

This software is released under the terms of the GNU General Public License v3.0.
See the [LICENSE](LICENSE) file for further information.
